#
# spec file for package restorecond
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libselinux_ver   3.7
Name:           restorecond
Version:        3.7
Release:        2.2
Summary:        Daemon to restore SELinux contexts
License:        GPL-2.0-or-later
Group:          Productivity/Security
URL:            https://github.com/SELinuxProject/selinux.git
Source0:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        restorecond.keyring
Patch0:         harden_restorecond.service.patch
Patch1:         1231512-Set-GLib-IO-channels-to-binary-mode.patch
Patch2:         1231512-Set-GLib-IO-channels-to-nonblocking.patch
BuildRequires:  dbus-1-glib-devel
BuildRequires:  libselinux-devel >= %{libselinux_ver}
Requires:       libselinux1 >= %{libselinux_ver}
Requires:       selinux-tools >= %{libselinux_ver}

%description
Daemon that watches for file creation and then sets the default SELinux file context

%prep
%setup -q
%patch -P0 -p1
%patch -P1 -p2
%patch -P2 -p2

%build
export CFLAGS="%optflags"
%make_build LSPP_PRIV=y all

%install
make DESTDIR=%{buildroot} SHLIBDIR=/%{_lib} SYSTEMDSYSTEMUNITDIR=%{_unitdir} SYSTEMDUSERUNITDIR=%{_userunitdir} install
rm %{buildroot}%{_sysconfdir}/rc.d/init.d/restorecond
ln -s /sbin/service %{buildroot}%{_sbindir}/rcrestorecond

%pre
%service_add_pre restorecond.service

%post
%service_add_post restorecond.service

%preun
%service_del_preun restorecond.service

%postun
%service_del_postun restorecond.service

%files
%dir %{_sysconfdir}/selinux
%config %{_sysconfdir}/selinux/restorecond.conf
%config(noreplace) %{_sysconfdir}/selinux/restorecond_user.conf
%{_sysconfdir}/xdg/autostart/restorecond.desktop
%{_unitdir}/restorecond.service
%{_userunitdir}/restorecond_user.service

%{_sbindir}/restorecond
%{_sbindir}/rcrestorecond
%{_datadir}/dbus-1/services/org.selinux.Restorecond.service
%{_mandir}/man8/restorecond.8%{?ext_man}

%changelog
* Thu Oct 24 2024 Cathy Hu <cathy.hu@suse.com>
- Fix issue where inotify events are not being handled properly
  * added: 1231512-Set-GLib-IO-channels-to-binary-mode.patch
- Fix issue where restorecond -u is not terminating with SIGTERM (bsc#1231512)
  * added: 1231512-Set-GLib-IO-channels-to-nonblocking.patch
* Mon Jul  1 2024 Cathy Hu <cathy.hu@suse.com>
- Update to version 3.7
  https://github.com/SELinuxProject/selinux/releases/tag/3.7
  * no changes from 3.6, only version changed to 3.7
* Tue Dec 19 2023 Cathy Hu <cathy.hu@suse.com>
- Update to version 3.6
  https://github.com/SELinuxProject/selinux/releases/tag/3.6
  * Add notself support for neverallow rules
  * Improve man pages
  * man pages: Remove the Russian translations
  * Add notself and other support to CIL
  * Add support for deny rules
  * Translations updated from
    https://translate.fedoraproject.org/projects/selinux/
  * Bug fixes
- Remove keys from keyring since they expired:
  - E853C1848B0185CF42864DF363A8AD4B982C4373
    Petr Lautrbach <plautrba@redhat.com>
  - 63191CE94183098689CAB8DB7EF137EC935B0EAF
    Jason Zaman <jasonzaman@gmail.com>
- Add key to keyring:
  - B8682847764DF60DF52D992CBC3905F235179CF1
    Petr Lautrbach <lautrbach@redhat.com>
* Mon Nov 27 2023 Hu <cathy.hu@suse.com>
- Change deprecated `%%patch1 -p1` syntax to supported `%%patch -P1 -p1`
  (bsc#1216669)
* Fri Feb 24 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.5
  * Code improvements, no user visible changes
- Added additional developer key (Jason Zaman)
* Mon May  9 2022 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.4
  * Support parallel relabeling
* Thu Dec  2 2021 Johannes Segitz <jsegitz@suse.com>
- Claim ownership for %%{_sysconfdir}/selinux
* Mon Nov 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_restorecond.service.patch
* Thu Nov 11 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.3
  * No user visible changes
* Tue Mar  9 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.2
  * Fix a double-close of a file descriptor
* Wed Jul 15 2020 Johannes Segitz <jsegitz@suse.com>
- Use proper macros for SYSTEMDSYSTEMUNITDIR and SYSTEMDUSERUNITDIR
* Tue Jul 14 2020 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.1
  * `restorecond_user.service` - new systemd user service which runs
    `restorecond -u`
* Tue May 12 2020 Johannes Segitz <jsegitz@suse.de>
- Use %%{_unitdir} for the location of the .service file
* Thu May  7 2020 pgajdos@suse.com
- %%{_libexecdir} now expands to /usr/libexec, so do not use it
  where /usr/lib was intended
* Tue Mar  3 2020 Johannes Segitz <jsegitz@suse.de>
- Update to version 3.0
  * Do not link against libpcre
  * Fix redundant console log output error
  * Use /run instead of /var/run
  Dropped r_opts_global.patch
* Wed Jan 15 2020 Johannes Segitz <jsegitz@suse.de>
- Added r_opts_global.patch to fix build problems with gcc due to
  multiple definitions for global symbols (bsc#1160290)
* Thu Dec  5 2019 Martin Liška <mliska@suse.cz>
- Use %%make_build and respect %%optflags.
* Wed Mar 20 2019 jsegitz@suse.com
- Update to version 2.9
  * Do not ignore the -f option
  * close the PID file if writing to it failed
* Tue Jan 15 2019 jsegitz@suse.com
- Package creation (already 2018-11-23, didn't include a .changes
  file then)
